import { h } from '@stencil/core';
// constants
import { MIN_VALUE, MAX_VALUE, API_URL } from './config';
// assets
import Logo from '../../assets/logo.svg';
export class XxilkWidget {
  constructor() {
    this.isLoading = false;
    this.handleLinkClick = () => {
      // window.open('https://google.com/search?q=learn+more', '_blank')
    };
    this.validateAmount = () => {
      const amount = Number(this.amount);
      return !isNaN(amount) && (amount >= MIN_VALUE) && (amount <= MAX_VALUE);
    };
    this.fetchAPI = () => {
      this.isLoading = true;
      fetch(`${API_URL}/financing/monthly-payment?amount=${this.amount}&language=${this.language}&b=${this.hash}`)
        .then((response) => response.json())
        .then((data) => this.paymentDetails = data)
        .catch((err) => console.error('Failed to fetch widget API', err))
        .finally(() => { this.isLoading = false; });
    };
    this.renderText = () => {
      const { interestRate, monthlySplitPaymentAmount, gracePeriodPaymentCount, monthlyPaymentStartingFromAmount, numberOfPayments, financingProductType, downPaymentAmount } = this.paymentDetails || {};
      switch (financingProductType) {
        case 'GRACE_PERIOD':
          return [
            downPaymentAmount > 0 && [
              h("span", null, `Get now with ${downPaymentAmount}€ down payment and ${monthlySplitPaymentAmount}€ X ${gracePeriodPaymentCount} (interest-free) payments`),
              h("br", null),
              h("span", null, `or split from ${monthlyPaymentStartingFromAmount}€ up to ${numberOfPayments} payments with ${interestRate}% interest rate`)
            ],
            downPaymentAmount === 0 && [
              'Get now, pay later!',
              h("br", null),
              `${monthlySplitPaymentAmount}€ X ${gracePeriodPaymentCount} (interest-free) payments`,
              h("br", null),
              h("span", null, `or split from ${monthlyPaymentStartingFromAmount}€ up to ${numberOfPayments} payments with ${interestRate}% interest rate`)
            ],
          ];
        case 'INSTALLMENT_CREDIT':
          return [
            'Get now, pay later!',
            h("br", null),
            `Split in ${numberOfPayments} payments with ${interestRate}% interest rate.`
          ];
        default:
          return 'No availiable deals for this purchase.';
      }
    };
    this.renderTooltipText = () => {
      const { interestRate, monthlySplitPaymentAmount, gracePeriodPaymentCount, monthlyPaymentStartingFromAmount, numberOfPayments, downPaymentAmount } = this.paymentDetails || {};
      const totalWithinGrace = downPaymentAmount + monthlySplitPaymentAmount * gracePeriodPaymentCount;
      return [
        `Interest Rate: ${interestRate}%`,
        `Grace period: ${gracePeriodPaymentCount || 'unavaliable'}`,
        `Monthly split payment: ${monthlySplitPaymentAmount || 0}€`,
        `Min per month payment: ${monthlyPaymentStartingFromAmount || 0}€`,
        `Number of payments: ${numberOfPayments}`,
        `Downpayment amount: ${downPaymentAmount}€`,
        `Total within grace period: ${gracePeriodPaymentCount > 0 ? totalWithinGrace + '€' : 'unavaliable'}`,
      ].map(item => [item, h("br", null)]);
    };
  }
  componentWillLoad() {
    if (!this.validateAmount())
      return;
    this.fetchAPI();
  }
  render() {
    if ((!this.paymentDetails || !this.validateAmount()) && !this.isLoading)
      return null;
    return (h("div", { class: 'widget-wrapper' }, h("div", { class: { logo: true, loading: this.isLoading }, innerHTML: Logo }), !this.isLoading && (h("div", { class: 'text-wrapper' }, h("p", { class: 'text' }, this.renderText(), h("span", { class: 'tooltip-wrapper' }, "i", h("span", { class: 'tooltip' }, this.renderTooltipText()))), h("button", { class: 'cta-button', onClick: this.handleLinkClick }, "Learn more")))));
  }
  static get is() { return "widget-xxilk"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["./widget-xxilk.css"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["widget-xxilk.css"]
    };
  }
  static get properties() {
    return {
      "amount": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "amount",
        "reflect": false
      },
      "language": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "Language",
          "resolved": "\"en\" | \"lt\" | \"lv\" | \"ru\"",
          "references": {
            "Language": {
              "location": "import",
              "path": "../../global.types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "language",
        "reflect": false
      },
      "hash": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "hash",
        "reflect": false
      }
    };
  }
  static get states() {
    return {
      "paymentDetails": {},
      "isLoading": {}
    };
  }
}
